@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Massachusetts Institute of Technology
+ * Copyright (c) 1997-1999, 2003 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 
 /* config.c -- this file contains all the codelets the system knows about */
 
-/* $Id: config_prelude,v 1.6 1998/08/31 16:28:47 fftw Exp $ */
+/* $Id: config_prelude,v 1.7 2000/03/02 21:58:53 stevenj Exp $ */
 
-#include <fftw-int.h>
+#include "fftw-int.h"
 
 /* the signature is the same as the size, for now */
 #define NOTW_CODELET(x) \
@@ -98,8 +98,7 @@ extern fftw_codelet_desc fftwi_twiddle_32_desc;
 extern fftw_codelet_desc fftw_twiddle_64_desc;
 extern fftw_codelet_desc fftwi_twiddle_64_desc;
 
-fftw_codelet_desc *fftw_config[] =
-{
+fftw_codelet_desc *fftw_config[] = {
      NOTW_CODELET(1),
      NOTWI_CODELET(1),
      NOTW_CODELET(2),
