@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1999 Massachusetts Institute of Technology
+ * Copyright (c) 1997-1999, 2003 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
  * executor.c -- execute the fft
  */
 
-/* $Id: executor.c,v 1.66 1999/10/26 21:41:29 stevenj Exp $ */
-#include <fftw-int.h>
+/* $Id: executor.c,v 1.68 2003/03/16 23:43:46 stevenj Exp $ */
+#include "fftw-int.h"
 #include <stdio.h>
 #include <stdlib.h>
 
-const char *fftw_version = "FFTW V" FFTW_VERSION " ($Id: executor.c,v 1.66 1999/10/26 21:41:29 stevenj Exp $)";
+const char *fftw_version = "FFTW V" FFTW_VERSION " ($Id: executor.c,v 1.68 2003/03/16 23:43:46 stevenj Exp $)";
 
 /*
  * This function is called in other files, so we cannot declare
