@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997,1998 Massachusetts Institute of Technology
+ * Copyright (c) 1997-1999, 2003 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
  *
  */
 
-/* $Id: fftwnd.c,v 1.39 1998/09/27 00:11:49 stevenj Exp $ */
+/* $Id: fftwnd.c,v 1.44 2003/03/16 23:43:46 stevenj Exp $ */
 
-#include <fftw-int.h>
+#include "fftw-int.h"
 
 /* the number of buffers to use for buffered transforms: */
 #define FFTWND_NBUFFERS 8
@@ -568,12 +568,25 @@ void fftw_buffered(fftw_plan p, int howmany,
 		    fftw_complex *cur_buffers = buffers + j;
 
 		    for (buf = 0; buf <= nbuffers - 4; buf += 4) {
-			 *cur_buffers = *cur_in2;
-			 *(cur_buffers += nb) = *(cur_in2 += idist);
-			 *(cur_buffers += nb) = *(cur_in2 += idist);
-			 *(cur_buffers += nb) = *(cur_in2 += idist);
-			 cur_buffers += nb;
-			 cur_in2 += idist;
+			 fftw_real r0, i0, r1, i1, r2, i2, r3, i3;
+			 r0 = c_re(cur_in2[0]);
+			 i0 = c_im(cur_in2[0]);
+			 r1 = c_re(cur_in2[idist]);
+			 i1 = c_im(cur_in2[idist]);
+			 r2 = c_re(cur_in2[2 * idist]);
+			 i2 = c_im(cur_in2[2 * idist]);
+			 r3 = c_re(cur_in2[3 * idist]);
+			 i3 = c_im(cur_in2[3 * idist]);
+			 c_re(cur_buffers[0]) = r0;
+			 c_im(cur_buffers[0]) = i0;
+			 c_re(cur_buffers[nb]) = r1;
+			 c_im(cur_buffers[nb]) = i1;
+			 c_re(cur_buffers[2 * nb]) = r2;
+			 c_im(cur_buffers[2 * nb]) = i2;
+			 c_re(cur_buffers[3 * nb]) = r3;
+			 c_im(cur_buffers[3 * nb]) = i3;
+			 cur_buffers += 4 * nb;
+			 cur_in2 += 4 * idist;
 		    }
 		    for (; buf < nbuffers; ++buf) {
 			 *cur_buffers = *cur_in2;
@@ -598,12 +611,25 @@ void fftw_buffered(fftw_plan p, int howmany,
 		    fftw_complex *cur_buffers = buffers + j;
 
 		    for (buf = 0; buf <= nbuffers - 4; buf += 4) {
-			 *cur_in2 = *cur_buffers;
-			 *(cur_in2 += idist) = *(cur_buffers += nb);
-			 *(cur_in2 += idist) = *(cur_buffers += nb);
-			 *(cur_in2 += idist) = *(cur_buffers += nb);
-			 cur_buffers += nb;
-			 cur_in2 += idist;
+			 fftw_real r0, i0, r1, i1, r2, i2, r3, i3;
+			 r0 = c_re(cur_buffers[0]);
+			 i0 = c_im(cur_buffers[0]);
+			 r1 = c_re(cur_buffers[nb]);
+			 i1 = c_im(cur_buffers[nb]);
+			 r2 = c_re(cur_buffers[2 * nb]);
+			 i2 = c_im(cur_buffers[2 * nb]);
+			 r3 = c_re(cur_buffers[3 * nb]);
+			 i3 = c_im(cur_buffers[3 * nb]);
+			 c_re(cur_in2[0]) = r0;
+			 c_im(cur_in2[0]) = i0;
+			 c_re(cur_in2[idist]) = r1;
+			 c_im(cur_in2[idist]) = i1;
+			 c_re(cur_in2[2 * idist]) = r2;
+			 c_im(cur_in2[2 * idist]) = i2;
+			 c_re(cur_in2[3 * idist]) = r3;
+			 c_im(cur_in2[3 * idist]) = i3;
+			 cur_buffers += 4 * nb;
+			 cur_in2 += 4 * idist;
 		    }
 		    for (; buf < nbuffers; ++buf) {
 			 *cur_in2 = *cur_buffers;
@@ -726,7 +752,7 @@ void fftwnd(fftwnd_plan p, int howmany,
 #ifdef FFTW_DEBUG
      if (p->rank > 0 && (p->plans[0]->flags & FFTW_THREADSAFE)
 	 && p->nwork && p->work)
-	  fftw_die("bug with FFTW_THREADSAFE flag");
+	  fftw_die("bug with FFTW_THREADSAFE flag\n");
 #endif
 
      if (p->nwork && !p->work)
